@@ -38,12 +38,18 @@ LOG = None
 
 dev_package_regex = re.compile(r'\ddev[-_]')
 
+def pypimirror_version():
+    """
+        returns a version string
+    """
+    version = pkg_resources.working_set.by_key["z3c.pypimirror"].version
+    return 'z3c.pypimirror/%s' % version
+
 def urlopen(url):
     """ This behaves exactly like urllib2.urlopen, but injects a header
         User-Agent: z3c.pypimirror/1.0.2
     """
-    version = pkg_resources.working_set.by_key["z3c.pypimirror"].version
-    headers = { 'User-Agent' : 'z3c.pypimirror/%s' % version }
+    headers = { 'User-Agent' : pypimirror_version() }
     req = urllib2.Request(url, None, headers)
     return urllib2.urlopen(req)
 
@@ -386,9 +392,11 @@ class Mirror(object):
     def _index_html(self):
         header = "<html><body><h1>PyPi Mirror</h1><h2>Last update: " + \
                  time.strftime("%c %Z")+"</h2>\n"
-        links = "<br />\n".join([self._html_link(link) for link in self.ls()])
+        _ls = self.ls()
+        links = "<br />\n".join([self._html_link(link) for link in _ls])
+        generator = "<p class='footer'>Generated by %s; %d packages mirrored.</p>" % (pypimirror_version(), len(_ls))
         footer = "</body></html>\n"
-        return "%s%s%s" % (header, links, footer)
+        return "\n".join((header, links, generator, footer))
 
     def index_html(self):
         content = self._index_html()
